.. _about:

=====
About
=====


Citation
--------

.. admonition:: Reference

   Gorgolewski, Krzysztof J. ; Esteban, Oscar ; Burns, Christopher ; Ziegler, Erik ; Pinsard, Basile ; Madison, Cindee ;
   Waskom, Michael ; Ellis, David Gage ; Clark, Dav ; Dayan, Michael ; Manhães-Savio, Alexandre ; Notter, Michael
   Philipp ; Johnson, Hans ; Dewey, Blake E ; Halchenko, Yaroslav O. ; Hamalainen, Carlo ; Keshavan, Anisha ; Clark,
   Daniel ; Huntenburg, Julia M. ; Hanke, Michael ; Nichols, B. Nolan ; Wassermann , Demian ; Eshaghi, Arman ;
   Markiewicz, Christopher ; Varoquaux, Gael ; Acland, Benjamin ; Forbes, Jessica ; Rokem, Ariel ; Kong, Xiang-Zhen ;
   Gramfort, Alexandre ; Kleesiek, Jens ; Schaefer, Alexander ; Sikka, Sharad ; Perez-Guevara, Martin Felipe ; Glatard,
   Tristan ; Iqbal, Shariq ; Liu, Siqi ; Welch, David ; Sharp, Paul ; Warner, Joshua ; Kastman, Erik ; Lampe, Leonie ;
   Perkins, L. Nathan ; Craddock, R. Cameron ; Küttner, René ; Bielievtsov, Dmytro ; Geisler, Daniel ; Gerhard,
   Stephan ; Liem, Franziskus ; Linkersdörfer, Janosch ; Margulies, Daniel S. ; Andberg, Sami Kristian ; Stadler,
   Jörg ; Steele, Christopher John ; Broderick, William ; Cooper, Gavin ; Floren, Andrew ; Huang, Lijie ; Gonzalez,
   Ivan ; McNamee, Daniel ; Papadopoulos Orfanos, Dimitri ; Pellman, John ; Triplett, William ; Ghosh, Satrajit
   (2016). Nipype: a flexible, lightweight and extensible neuroimaging data processing framework in Python.
   0.12.0-rc1. Zenodo. `10.5281/zenodo.50186 <http://dx.doi.org/10.5281/zenodo.50186>`_

::

    @misc{gorgolewski_2016_50186,
      author       = {Gorgolewski, Krzysztof J. and
                      Esteban, Oscar and
                      Burns, Christopher and
                      Ziegler, Erik and
                      Pinsard, Basile and
                      Madison, Cindee and
                      Waskom, Michael and
                      Ellis, David Gage and
                      Clark, Dav and
                      Dayan, Michael and
                      Manhães-Savio, Alexandre and
                      Notter, Michael Philipp and
                      Johnson, Hans and
                      Dewey, Blake E and
                      Halchenko, Yaroslav O. and
                      Hamalainen, Carlo and
                      Keshavan, Anisha and
                      Clark, Daniel and
                      Huntenburg, Julia M. and
                      Hanke, Michael and
                      Nichols, B. Nolan and
                      Wassermann , Demian and
                      Eshaghi, Arman and
                      Markiewicz, Christopher and
                      Varoquaux, Gael and
                      Acland, Benjamin and
                      Forbes, Jessica and
                      Rokem, Ariel and
                      Kong, Xiang-Zhen and
                      Gramfort, Alexandre and
                      Kleesiek, Jens and
                      Schaefer, Alexander and
                      Sikka, Sharad and
                      Perez-Guevara, Martin Felipe and
                      Glatard, Tristan and
                      Iqbal, Shariq and
                      Liu, Siqi and
                      Welch, David and
                      Sharp, Paul and
                      Warner, Joshua and
                      Kastman, Erik and
                      Lampe, Leonie and
                      Perkins, L. Nathan and
                      Craddock, R. Cameron and
                      Küttner, René and
                      Bielievtsov, Dmytro and
                      Geisler, Daniel and
                      Gerhard, Stephan and
                      Liem, Franziskus and
                      Linkersdörfer, Janosch and
                      Margulies, Daniel S. and
                      Andberg, Sami Kristian and
                      Stadler, Jörg and
                      Steele, Christopher John and
                      Broderick, William and
                      Cooper, Gavin and
                      Floren, Andrew and
                      Huang, Lijie and
                      Gonzalez, Ivan and
                      McNamee, Daniel and
                      Papadopoulos Orfanos, Dimitri and
                      Pellman, John and
                      Triplett, William and
                      Ghosh, Satrajit},
      title        = {{Nipype: a flexible, lightweight and extensible
                       neuroimaging data processing framework in Python.
                       0.12.0-rc1}},
      month        = apr,
      year         = 2016,
      doi          = {10.5281/zenodo.50186},
      url          = {http://dx.doi.org/10.5281/zenodo.50186}
    }

When publishing results obtained using Nipype we strongly encourage citing the above reference to give credit to all
Nipype contributors. However, if for some reason the journal you are publishing with does not allow you do cite software
this way you can use the initial paper published in 2011 (see below).

.. admonition:: Reference

   Gorgolewski K, Burns CD, Madison C, Clark D, Halchenko YO, Waskom ML,
   Ghosh SS. (2011). Nipype: a flexible, lightweight and extensible neuroimaging
   data processing framework in Python. Front. Neuroimform. 5:13.

   `Download Paper`__

   __ paper_

::

    @article { Gorgolewski2011,
	title            = "Nipype: a flexible, lightweight and extensible neuroimaging data processing framework in python.",
	year             = "2011",
	author           = "Krzysztof Gorgolewski and Christopher D Burns and Cindee Madison and Dav Clark and Yaroslav O Halchenko and Michael L Waskom and Satrajit S Ghosh",
	journal          = "Front Neuroinform",
	volume           = "5",
	month            = "08",
	doi              = "10.3389/fninf.2011.00013",
	pubmed           = "21897815",
	url              = "http://dx.doi.org/10.3389/fninf.2011.00013",
	issn             = "1662-5196"}


.. include:: links_names.txt


.. include:: ../THANKS.rst
